@@ -13,15 +13,17 @@ Puppet::Type.type(:cinder_type).provide(
 
   def create
     properties = []
-    resource[:properties].each do |item|
-      properties << '--property' << item
+    if resource[:properties]
+      resource[:properties].each do |k, v|
+        properties << '--property' << "#{k}=#{v}"
+      end
     end
     properties << (@resource[:is_public] == :true ? '--public' : '--private')
     properties << name
     self.class.request('volume type', 'create', properties)
     @property_hash[:ensure] = :present
     @property_hash[:properties] = resource[:properties]
-    @property_hash[:is_public] = resource[:is_public]
+    @property_hash[:is_public] = resource[:is_public].downcase.to_sym
     @property_hash[:name] = name
     unless @resource[:access_project_ids].nil?
       set_access_project_ids(resource[:access_project_ids])
@@ -40,8 +42,10 @@ Puppet::Type.type(:cinder_type).provide(
 
   def properties=(value)
     properties = []
-    (value - @property_hash[:properties]).each do |item|
-      properties << '--property' << item
+    @property_hash[:properties].each do |k, v|
+      if value[k] != v
+        properties << '--property' << "#{k}=#{value[k]}"
+      end
     end
     unless properties.empty?
       self.class.request('volume type', 'set', [properties, name])
@@ -80,11 +84,11 @@ Puppet::Type.type(:cinder_type).provide(
     list.each do |type|
       if type[:is_public] == 'False'
         type_details = request('volume type', 'show', type[:id])
-        type[:access_project_ids] = parsestring(type_details[:access_project_ids])
-        type[:is_public] = false
+        type[:access_project_ids] = string2array(type_details[:access_project_ids])
+        type[:is_public] = :false
       else
         type[:access_project_ids] = []
-        type[:is_public] = true
+        type[:is_public] = :true
       end
     end
 
@@ -93,7 +97,7 @@ Puppet::Type.type(:cinder_type).provide(
         :name               => type[:name],
         :ensure             => :present,
         :id                 => type[:id],
-        :properties         => parsestring(type[:properties]),
+        :properties         => parse_python_dict(type[:properties]),
         :is_public          => type[:is_public],
         :access_project_ids => type[:access_project_ids]
       })
@@ -112,23 +116,4 @@ Puppet::Type.type(:cinder_type).provide(
   def self.string2array(input)
     return input.delete("'").split(/,\s/)
   end
-
-  def self.pythondict2array(input)
-    json_input = JSON.parse(input.gsub(/'/, '"'))
-    output = []
-    json_input.each do | k, v |
-      output = output + ["#{k}=#{v}"]
-    end
-    return output
-  end
-
-  def self.parsestring(input)
-    if input[0] == '{'
-      # 4.0.0+ output, python dict
-      return self.pythondict2array(input)
-    else
-      # Pre-4.0.0 output, key=value
-      return self.string2array(input)
-    end
-  end
 end
