@@ -8,22 +8,21 @@ Puppet::Type.newtype(:cinder_type) do
     newvalues(/\S+/)
   end
 
-  newproperty(:properties, :array_matching => :all) do
-    desc 'The properties of the cinder type. Should be an array, all items should match pattern <key=value>'
-    defaultto []
-    def insync?(is)
-      return false unless is.is_a? Array
-      is.sort == should.sort
-    end
+  newproperty(:properties) do
+    desc "The set of volume type properties"
     validate do |value|
-      raise ArgumentError, "Properties doesn't match" unless value.match(/^[^=\s]+=[^=]+$/)
+      if value.is_a?(Hash)
+        return true
+      else
+        raise ArgumentError, "Invalid properties #{value}. Requires a Hash, not a #{value.class}"
+      end
     end
   end
 
-  newparam(:is_public, :boolean => true) do
+  newproperty(:is_public, :boolean => true) do
     desc 'Whether the type is public or not. Default to `true`'
     newvalues(:true, :false)
-    defaultto true
+    defaultto :true
   end
 
   newproperty(:access_project_ids,  :array_matching => :all) do
