@@ -16,7 +16,30 @@ describe 'basic cinder' do
       include openstack_integration::cinder
 
       cinder_type { 'testvolumetype' :
-        properties => ['k=v', 'key1=val1', 'key2=<is> True']
+        properties => {
+          'k'    => 'v',
+          'key1' => 'val1',
+          'key2' => '<is> True'
+        }
+      }
+
+      cinder_type { 'qostype1':
+        ensure => present
+      }
+      cinder_type { 'qostype2':
+        ensure => present
+      }
+      cinder_qos { 'testqos1':
+        properties   => {
+          'key1' => 'val1',
+          'key2' => 'val2',
+        }
+      }
+      cinder_qos { 'testqos2':
+        associations => ['qostype1', 'qostype2']
+      }
+      cinder_qos { 'testqos3':
+        consumer => 'front-end',
       }
       EOS
 
