@@ -38,9 +38,7 @@ describe 'cinder::api' do
           :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
           :max_request_body_size        => '<SERVICE DEFAULT>',
         )
-        is_expected.to contain_cinder_config('ssl/ca_file').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('ssl/cert_file').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('ssl/key_file').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_oslo__service__ssl('cinder_config')
       end
     end
 
@@ -176,22 +174,6 @@ describe 'cinder::api' do
       end
     end
 
-    context 'when service_name is not valid' do
-      let :params do
-        req_params.merge!({ :service_name => 'foobar' })
-      end
-
-      let :pre_condition do
-        "include apache
-         class { 'cinder': }
-         class { 'cinder::keystone::authtoken':
-           password => 'foo',
-         }"
-      end
-
-      it_raises 'a Puppet::Error', /Invalid service_name/
-    end
-
     context 'with SSL socket options set' do
       let :params do
         req_params.merge!({
@@ -202,9 +184,11 @@ describe 'cinder::api' do
         })
       end
 
-      it { is_expected.to contain_cinder_config('ssl/ca_file').with_value('/path/to/ca') }
-      it { is_expected.to contain_cinder_config('ssl/cert_file').with_value('/path/to/cert') }
-      it { is_expected.to contain_cinder_config('ssl/key_file').with_value('/path/to/key') }
+      it { is_expected.to contain_oslo__service__ssl('cinder_config').with(
+        :ca_file   => '/path/to/ca',
+        :cert_file => '/path/to/cert',
+        :key_file  => '/path/to/key'
+      )}
     end
 
     context 'with SSL socket options set wrongly configured' do
