@@ -103,11 +103,11 @@ describe 'cinder::backup' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge(OSDefaults.get_facts({:os_workers => 8}))
+        facts.merge(OSDefaults.get_facts())
       end
 
       let :platform_params do
-        if facts[:osfamily] == 'Debian'
+        if facts[:os]['family'] == 'Debian'
           { :backup_package => 'cinder-backup',
             :backup_service => 'cinder-backup' }
         else
