@@ -28,11 +28,11 @@ describe 'cinder' do
           :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
           :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
           :heartbeat_rate                  => '<SERVICE DEFAULT>',
-          :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
           :rabbit_qos_prefetch_count       => '<SERVICE DEFAULT>',
           :kombu_reconnect_delay           => '<SERVICE DEFAULT>',
           :kombu_failover_strategy         => '<SERVICE DEFAULT>',
           :amqp_durable_queues             => '<SERVICE DEFAULT>',
+          :amqp_auto_delete                => '<SERVICE DEFAULT>',
           :kombu_compression               => '<SERVICE DEFAULT>',
           :kombu_ssl_ca_certs              => '<SERVICE DEFAULT>',
           :kombu_ssl_certfile              => '<SERVICE DEFAULT>',
@@ -42,9 +42,12 @@ describe 'cinder' do
           :rabbit_retry_interval           => '<SERVICE DEFAULT>',
           :rabbit_quorum_queue             => '<SERVICE DEFAULT>',
           :rabbit_transient_quorum_queue   => '<SERVICE DEFAULT>',
+          :rabbit_transient_queues_ttl     => '<SERVICE DEFAULT>',
           :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
+          :use_queue_manager               => '<SERVICE DEFAULT>',
+          :rabbit_stream_fanout            => '<SERVICE DEFAULT>',
           :enable_cancel_on_failover       => '<SERVICE DEFAULT>',
         )
         is_expected.to contain_oslo__messaging__notifications('cinder_config').with(
@@ -58,8 +61,8 @@ describe 'cinder' do
       it {
         is_expected.to contain_cinder_config('DEFAULT/report_interval').with(:value => '<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/service_down_time').with(:value => '<SERVICE DEFAULT>')
-        is_expected.to contain_cinder_config('DEFAULT/storage_availability_zone').with(:value => 'nova')
-        is_expected.to contain_cinder_config('DEFAULT/default_availability_zone').with(:value => 'nova')
+        is_expected.to contain_cinder_config('DEFAULT/storage_availability_zone').with(:value => '<SERVICE DEFAULT>')
+        is_expected.to contain_cinder_config('DEFAULT/default_availability_zone').with(:value => '<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/allow_availability_zone_fallback').with(:value => '<SERVICE DEFAULT>')
         is_expected.to contain_cinder_config('DEFAULT/api_paste_config').with(:value => '/etc/cinder/api-paste.ini')
         is_expected.to contain_oslo__concurrency('cinder_config').with(
@@ -98,13 +101,15 @@ describe 'cinder' do
         req_params.merge(
           :rabbit_heartbeat_timeout_threshold => '60',
           :rabbit_heartbeat_rate              => '10',
-          :rabbit_heartbeat_in_pthread        => true,
           :rabbit_qos_prefetch_count          => 0,
           :rabbit_quorum_queue                => true,
           :rabbit_transient_quorum_queue      => true,
+          :rabbit_transient_queues_ttl        => 60,
           :rabbit_quorum_delivery_limit       => 3,
           :rabbit_quorum_max_memory_length    => 5,
           :rabbit_quorum_max_memory_bytes     => 1073741824,
+          :rabbit_use_queue_manager           => true,
+          :rabbit_stream_fanout               => true,
           :rabbit_enable_cancel_on_failover   => false,
         )
       end
@@ -112,13 +117,15 @@ describe 'cinder' do
       it { is_expected.to contain_oslo__messaging__rabbit('cinder_config').with(
         :heartbeat_timeout_threshold     => '60',
         :heartbeat_rate                  => '10',
-        :heartbeat_in_pthread            => true,
         :rabbit_qos_prefetch_count       => 0,
         :rabbit_quorum_queue             => true,
         :rabbit_transient_quorum_queue   => true,
+        :rabbit_transient_queues_ttl     => 60,
         :rabbit_quorum_delivery_limit    => 3,
         :rabbit_quorum_max_memory_length => 5,
         :rabbit_quorum_max_memory_bytes  => 1073741824,
+        :use_queue_manager               => true,
+        :rabbit_stream_fanout            => true,
         :enable_cancel_on_failover       => false,
       ) }
     end
